Fix typo in site_server_job_utils. Wrong version got submitted.

The perils of having the commit window open after making and testing a
change :-/ Fixes typo introduced by http://gerrit.chromium.org/gerrit/5413

BUG=none
TEST=running in production.

Change-Id: I7112ffacc70b307f313ef36c2926f7c9c6ae6197
Reviewed-on: http://gerrit.chromium.org/gerrit/5667
Reviewed-by: Scott Zawalski <scottz@chromium.org>
Tested-by: Dale Curtis <dalecurtis@chromium.org>
diff --git a/server/site_server_job_utils.py b/server/site_server_job_utils.py
index b1a9d37..87a66d3 100644
--- a/server/site_server_job_utils.py
+++ b/server/site_server_job_utils.py
@@ -197,12 +197,12 @@
         If continuous parsing was requested, start the parser before running
         tests.
         """
         # Modify self.resultdir so that it points to the results directory for
         # the machine we're working on. Required so that server jobs will write
         # to the proper location.
         self._server_job.machines = [self._machine]
         self._server_job.push_execution_context(self._machine)
-        os.chdir(self.resultdir)
+        os.chdir(self._server_job.resultdir)
         if self._continuous_parsing:
             self._server_job._parse_job += "/" + self._machine
             self._server_job._using_parser = True
@@ -197,12 +197,12 @@
         tests.
         """
-        # Modify self.resultdir so that it points to the results directory for
+        # Modify job.resultdir so that it points to the results directory for
         # the machine we're working on. Required so that server jobs will write
         # to the proper location.